@@ -30,18 +30,12 @@
 #include <stdarg.h>
 #include <stdio.h>
 #include <string.h>
-#if !defined(_MSC_VER)
+#if defined(__MINGW32__)
 #include <sys/param.h>
 #endif
 #include <time.h>
 #include "physicalunits.h"
 
-#ifdef __cplusplus
-#define EXTERN_C extern "C"
-#else
-#define EXTERN_C
-#endif
-
 
 #ifdef __cplusplus
 extern "C" {
@@ -50,7 +44,7 @@ extern "C" {
 #ifdef NDEBUG
 #define VERBOSE_LEVEL 0 	// turn off debugging information, but its only used without NDEBUG
 #else
-extern int VERBOSE_LEVEL; 	// used for debugging, variable is always defined
+extern int VERBOSE_LEVEL __attribute__ ((visibility ("default") )); 	// used for debugging, variable is always defined
 #endif
 
 
@@ -114,7 +108,7 @@ char *getlogin (void);
 
 #define BIOSIG_VERSION_MAJOR 1
 #define BIOSIG_VERSION_MINOR 9
-#define BIOSIG_PATCHLEVEL    0
+#define BIOSIG_PATCHLEVEL    5
 // for backward compatibility
 #define BIOSIG_VERSION_STEPPING BIOSIG_PATCHLEVEL
 #define BIOSIG_VERSION (BIOSIG_VERSION_MAJOR * 10000 + BIOSIG_VERSION_MINOR * 100 + BIOSIG_PATCHLEVEL)
@@ -143,7 +137,7 @@ char *getlogin (void);
 #include "gdftime.h"
 
 /*
- * pack structures to fullfil following requirements:
+ * pack structures to fulfil following requirements:
  * (1) Matlab v7.3+ requires 8 byte alignment
  * (2) in order to use mingw-compiled libbiosig with MS' VisualStudio,
  *     the structurs must be packed in a MS compatible way.
@@ -231,8 +225,9 @@ enum FileFormat {
 	SPSS, STATA, SVG, SXI, SYNERGY,
 	TDMS, TIFF, TMS32, TMSiLOG, TRC, UNIPRO, VRML, VTK,
 	WAV, WCP, WG1, WinEEG, WMF, XML, XPM,
-	Z, ZIP, ZIP2, RHD2000,
-	invalid=0xffff
+	Z, ZIP, ZIP2, RHD2000, RHS2000, IntanCLP,
+	EBNEURO, SigViewerEventsCSV, XDF,
+	LastPlaceHolder, invalid=0xffff
 };
 
 
@@ -538,10 +533,15 @@ struct NomenclatureAnnotatedECG_t {
 	const char *refid;
 } ATT_MSSTRUCT;
 
-extern const struct etd_t ETD [];
-extern const struct event_groups_t EventCodeGroups [];
+extern const struct etd_t ETD [] __attribute__ ((visibility ("default") ));
+extern const struct event_groups_t EventCodeGroups [] __attribute__ ((visibility ("default") ));
 extern const struct FileFormatStringTable_t FileFormatStringTable [];
 
+typedef struct {
+	const char *free_text_event_limiter;
+} biosig_options_type;
+
+HDRTYPE* sopen_extended(const char* FileName, const char* MODE, HDRTYPE* hdr, biosig_options_type* options) __attribute__ ((visibility ("default") ));
 
 /* reset structure packing to default settings */
 #pragma pack(pop)
@@ -578,9 +578,9 @@ extern const struct FileFormatStringTable_t FileFormatStringTable [];
 #  define bswap_64(x) __builtin_bswap64(x)
 
 #	include <winsock2.h>
-#   if !defined(_MSC_VER)
+#	if defined(__MINGW32__)
 #	    include <sys/param.h>
-#   endif
+#	endif
 #	if BYTE_ORDER == LITTLE_ENDIAN
 #		define htobe16(x) htons(x)
 #		define htole16(x) (x)
@@ -593,15 +593,15 @@ extern const struct FileFormatStringTable_t FileFormatStringTable [];
 #		define le32toh(x) (x)
 
 #		define htole64(x) (x)
-#       if !defined(_MSC_VER)
-#           define htobe64(x) __builtin_bswap64(x)
-#           define be64toh(x) __builtin_bswap64(x)
-#       else
-#           define ntohll(x) (((_int64)(ntohl((int)((x << 32) >> 32))) << 32) | (unsigned int)ntohl(((int)(x >> 32))))
-#           define htonll(x) ntohll(x)
-#           define htobe64(x) htonll(x)
-#           define be64toh(x) ntohll(x)
-#       endif
+#		if defined(__MINGW32__)
+#       	    define htobe64(x) __builtin_bswap64(x)
+#       	    define be64toh(x) __builtin_bswap64(x)
+#       	else
+#       	    define ntohll(x) (((_int64)(ntohl((int)((x << 32) >> 32))) << 32) | (unsigned int)ntohl(((int)(x >> 32))))
+#       	    define htonll(x) ntohll(x)
+#       	    define htobe64(x) htonll(x)
+#       	    define be64toh(x) ntohll(x)
+#       	endif
 #		define le64toh(x) (x)
 
 #	elif BYTE_ORDER == BIG_ENDIAN
@@ -930,9 +930,6 @@ static inline void bef64a(  double i, void* r) {
 #ifndef isfinite
 # define isfinite(a) (-INFINITY < (a) && (a) < INFINITY)
 #endif
-#ifndef isnan
-# define isnan(a) ((a)!=(a))
-#endif
 
 /*
     The macro IS_SET() can be used to test for defines in 
@@ -1065,6 +1062,8 @@ typedef struct aecg {
 /**                                                                        **/
 /****************************************************************************/
 
+#pragma GCC visibility push(default)
+
 /*
         file access wrapper: use ZLIB (if available) or STDIO
  */
@@ -1091,6 +1090,8 @@ int             iferror(HDRTYPE* hdr);
 uint32_t gcd(uint32_t A, uint32_t B);
 uint32_t lcm(uint32_t A, uint32_t B);
 
+#pragma GCC visibility pop
+
 extern const uint16_t GDFTYP_BITS[];
 extern const char *LEAD_ID_TABLE[];
 
@@ -1111,7 +1112,7 @@ int month_string2int(const char *s);
 
 int u32cmp(const void *a, const void *b); 
 
-void biosigERROR(HDRTYPE *hdr, enum B4C_ERROR errnum, const char *errmsg);
+void biosigERROR(HDRTYPE *hdr, enum B4C_ERROR errnum, const char *errmsg) __attribute__ ((visibility ("default") ));
 /*
 	sets the local and the (deprecated) global error variables B4C_ERRNUM and B4C_ERRMSG
 	the global error variables are kept for backwards compatibility.
@@ -1124,8 +1125,8 @@ void biosigERROR(HDRTYPE *hdr, enum B4C_ERROR errnum, const char *errmsg);
 	therefore not exported to standard user applications. 
 */
 
-void struct2gdfbin(HDRTYPE *hdr);
-int gdfbin2struct(HDRTYPE *hdr);
+void struct2gdfbin(HDRTYPE *hdr) __attribute__ ((visibility ("default") ));
+int gdfbin2struct(HDRTYPE *hdr) __attribute__ ((visibility ("default") ));
 /* struct2gdfbin and gdfbin2struct
 	convert between the streamed header information (as in a GDF file or 
 	on a network connection) and the header structure HDRTYPE 
@@ -1135,14 +1136,14 @@ int gdfbin2struct(HDRTYPE *hdr);
 	event table itself. 
  ------------------------------------------------------------------------*/
 
-size_t hdrEVT2rawEVT(HDRTYPE *hdr);
-void rawEVT2hdrEVT(HDRTYPE *hdr, size_t length_rawEventTable);
+size_t hdrEVT2rawEVT(HDRTYPE *hdr) __attribute__ ((visibility ("default") ));
+void rawEVT2hdrEVT(HDRTYPE *hdr, size_t length_rawEventTable) __attribute__ ((visibility ("default") ));
 /* rawEVT2hdrEVT and hdrEVT2rawEVT
 	convert between streamed event table and the structure
 	HDRTYPE.EVENT.
  ------------------------------------------------------------------------*/
 
-int NumberOfChannels(HDRTYPE *hdr); 
+int NumberOfChannels(HDRTYPE *hdr) __attribute__ ((visibility ("default") ));
 /*
         returns the number of channels returned by SREAD. 
         This might be different than the number of data channels in the file
@@ -1161,7 +1162,7 @@ void FreeGlobalEventCodeTable();
 	free memory allocated for global event code
  ------------------------------------------------------------------------*/
 
-size_t	sread_raw(size_t START, size_t LEN, HDRTYPE* hdr, char flag, void *buf, size_t bufsize);
+size_t	sread_raw(size_t START, size_t LEN, HDRTYPE* hdr, char flag, void *buf, size_t bufsize) __attribute__ ((visibility ("default") ));
 /* sread_raw: 
 	LEN data segments are read from file associated with hdr, starting from 
 	segment START.
@@ -1185,7 +1186,7 @@ size_t	sread_raw(size_t START, size_t LEN, HDRTYPE* hdr, char flag, void *buf, s
 	block and the number of blocks, respectively.  
  --------------------------------------------------------------- */
 
-size_t bpb8_collapsed_rawdata(HDRTYPE *hdr);
+size_t bpb8_collapsed_rawdata(HDRTYPE *hdr) __attribute__ ((visibility ("default") ));
 /* bpb8_collapsed_rawdata
 	computes the bits per block when rawdata is collapsed
 --------------------------------------------------------------- */
@@ -1200,11 +1201,11 @@ HDRTYPE* getfiletype(HDRTYPE* hdr);
 		hdr->VERSION	is defined for some selected formats e.g. ACQ, EDF, BDF, GDF
  --------------------------------------------------------------- */
 
-const char* GetFileTypeString(enum FileFormat FMT);
+const char* GetFileTypeString(enum FileFormat FMT) __attribute__ ((visibility ("default") ));
 /*	returns a string with file format
  --------------------------------------------------------------- */
 
-enum FileFormat GetFileTypeFromString(const char *);
+enum FileFormat GetFileTypeFromString(const char *) __attribute__ ((visibility ("default") ));
 /*	returns file format from string
  --------------------------------------------------------------- */
 
