@@ -27,6 +27,7 @@
 #include <stddef.h>
 */
 #include <ctype.h>
+#include <math.h>      // define macro isnan()
 #include <stdlib.h>
 #include <string.h>
 #include "../biosig-dev.h"
@@ -896,12 +897,12 @@ void sopen_itx_read (HDRTYPE* hdr) {
 		}
 
                 if (VERBOSE_LEVEL>7)
-                        fprintf(stdout,"%s (line %i): scaning %s,v%4.2f format (supported: %i)\n",__FILE__,__LINE__,GetFileTypeString(hdr->TYPE),hdr->VERSION,flagSupported);
+                        fprintf(stdout,"%s (line %i): scanning %s,v%4.2f format (supported: %i)\n",__FILE__,__LINE__,GetFileTypeString(hdr->TYPE),hdr->VERSION,flagSupported);
 
 		if (!flagSupported) {
 			clear_sweepnames(sweepname_list);
 			biosigERROR(hdr, hdr->AS.B4C_ERRNUM,
- "This ITX format is not supported. Possible reasons: not generated by Heka-Patchmaster, corrupted, physical units do not match between sweeos, or do not fullfil some other requirements");
+ "This ITX format is not supported. Possible reasons: not generated by Heka-Patchmaster, corrupted, physical units do not match between sweeps, or do not fulfil some other requirements");
 			return;
 		}
 
