@@ -25,7 +25,7 @@
 #define DEFAULT_TIME_HYSTERESIS  1     // Two sequences of time hysteresis.
 
 
-#if defined(__linux__) || defined(__STF__) || defined(__APPLE__) || defined(__MINGW32__)
+#if !defined(_WINDOWS) || defined(__MINGW32__) || defined(__STF__)
 	#define max(a,b)   (((a) > (b)) ? (a) : (b))
 	#define min(a,b)   (((a) < (b)) ? (a) : (b))
 #endif
