@@ -14,7 +14,7 @@
 extern "C" {
 #endif
 
-#if defined(_WINDOWS) && !defined(__MINGW32__)
+#if defined(_MSC_VER)
     #include <windows.h>
     #include <stdio.h>
     typedef HANDLE FILEHANDLE;
@@ -35,6 +35,8 @@ extern "C" {
 #include "../AxAbfFio32/AxAbffio32.h"
     
 #include <stdio.h>
+    typedef FILE* FILEHANDLE;
+
 //
 // Commonly used typedefs & constants from windows.h.
 //
@@ -94,7 +96,14 @@ typedef const CHAR *LPCSTR, *PCSTR;
 //
 // Neutral ANSI/UNICODE types and macros
 //
-#if !defined(_WINDOWS) || defined(UNICODE) || defined(__MINGW32__)                     // r_winnt
+
+#if defined(__MINGW32__)
+   #include <stdarg.h>
+   #include <windef.h>
+   #include <winbase.h>
+#else
+
+#if defined(UNICODE)  		   // r_winnt
 
 #ifndef _TCHAR_DEFINED
 typedef WCHAR TCHAR, *PTCHAR;
@@ -123,8 +132,6 @@ typedef LPCSTR LPCTSTR;
 
 #endif /* UNICODE */                // r_winnt
 
-typedef FILE* FILEHANDLE;
-
 // Handle declarations.
 typedef void          *HANDLE;
 typedef HANDLE         HINSTANCE;
@@ -134,7 +141,13 @@ typedef void          *LPOVERLAPPED;
 typedef void          *LPSECURITY_ATTRIBUTES;
 
 typedef long long      LONGLONG;
+#if  defined(_WIN64)
+typedef unsigned __int64 UINT_PTR;
+#else
 typedef unsigned int   UINT_PTR;
+#endif
+#endif  //
+
 #define DWORD_PTR UINT_PTR
 
 #define FILE_BEGIN                          0
@@ -181,27 +194,26 @@ typedef unsigned int   UINT_PTR;
 #define cdecl
 #define WINAPI __stdcall
 
+#ifndef GUID_DEFINED
 typedef struct _GUID
 {
+    // TODO: for WIN64 this need to be redefined
     unsigned int   Data1;
     unsigned short Data2;
     unsigned short Data3;
     unsigned char  Data4[ 8 ];
 } GUID;
 #define GUID_DEFINED
+#endif
 
 void _splitpath(const char* inpath, char * drv, char * dir,
                 char* fname, char * ext );
 int _strnicmp( LPCSTR str1, LPCSTR str2, size_t n );
-inline int strnicmp( const char* s1, const char* s2, size_t n ) { 
-    return _strnicmp( s1, s2, n );
-}
 void _makepath( char * path, const char * drive,
                 const char *directory, const char * filename,
                 const char * extension );
 
-#ifndef _FILETIME_
-#define _FILETIME_
+#if !defined(__MINGW32__)
 /* 64 bit number of 100 nanoseconds intervals since January 1, 1601 */
 typedef struct _FILETIME
 {
@@ -213,7 +225,6 @@ typedef struct _FILETIME
     DWORD  dwHighDateTime;
 #endif
 } FILETIME, *PFILETIME, *LPFILETIME;
-#endif /* _FILETIME_ */
 
 typedef struct _SYSTEMTIME{
     WORD wYear;
@@ -225,8 +236,9 @@ typedef struct _SYSTEMTIME{
     WORD wSecond;
     WORD wMilliseconds;
 } SYSTEMTIME, *PSYSTEMTIME, *LPSYSTEMTIME;
+#endif // __MINGW32__
 
-#endif
+#endif // _MSC_VER
 
 extern HINSTANCE g_hInstance;
 
