@@ -17,9 +17,9 @@
 #include "../axon/AxAbfFio32/abffiles.h"
 #include <math.h>
 
-#if defined(__linux__) || defined(__STF__) || defined(__APPLE__) || defined(__MINGW32__)
-#define max(a,b)   (((a) > (b)) ? (a) : (b))
-#define min(a,b)   (((a) < (b)) ? (a) : (b))
+#if !defined(_WINDOWS) || defined(__MINGW32__) || defined(__STF__)
+	#define max(a,b)   (((a) > (b)) ? (a) : (b))
+	#define min(a,b)   (((a) < (b)) ? (a) : (b))
 #endif
 
 extern  BOOL GetNewFileDescriptor(CFileDescriptor **ppFI, int *pnFile, int *pnError);
