@@ -5,4 +5,7 @@ Python module to read common electrophysiology file formats.
 
 from .stfio import *
 from . import stfio_plot as plot
-from . import stfio_neo as neo
+try:
+    from . import stfio_neo as neo
+except ImportError:
+    pass
